@@ -1,7 +1,7 @@
 /*
- * $Id: booster.h 8466 2006-11-29 14:50:24Z guillem $
+ * $Id: booster.h 12991 2007-08-01 22:23:38Z guillem $
  *
- * Copyright (C) 2005, 2006 Nokia Corporation
+ * Copyright (C) 2005, 2006, 2007 Nokia Corporation
  *
  * Author: Guillem Jover <guillem.jover@nokia.com>
  *
@@ -20,28 +20,23 @@
  *
  */
 
-#ifndef LAUNCHER_BOOSTER_H
-#define LAUNCHER_BOOSTER_H
+#ifndef BOOSTER_H
+#define BOOSTER_H
 
-typedef void *booster_state_t;
+#include "booster_api.h"
 
-typedef struct {
-  int booster_version;
-  booster_state_t (*booster_preinit)(int *argc, char **argv[]);
-  void (*booster_init)(const char *progfilename, const booster_state_t state);
-  void (*booster_reload)(booster_state_t state);
-} booster_api_t;
-
-#define BOOSTER_API_VERSION 0
-
-typedef struct {
+typedef struct booster {
   booster_state_t	state;
   booster_api_t		*api;
   void			*so;
   const char		*name;
+  struct booster	*next;
 } booster_t;
 
-void booster_module_load(booster_t *mod);
+void boosters_alloc(booster_t **booster, const char *arg);
+void boosters_load(booster_t *booster, int *argc, char **argv[]);
+void boosters_init(booster_t *booster, char *argv0);
+void boosters_reload(booster_t *booster);
 
 #endif
 
